Super Zippy
===========

Super Zippy will take a Python package and create a single executable file out of it that you can distribute to all your Linux user friends.

```bash
$ echo "entry_point = 'superzippy.packaging:run'" > superconfig.py
$ superzippy superzippy
```

And now we have a single file containing all of Super Zippy's dependencies and code. No installation necessary.

Authors
-------

John Sullivan

License
-------

None yet, you have no license to use this O.O. I'll stick licensing around when I'm ready, it'll be under Apache v2.0. If you're impatient badger me with emails.
